summaryrefslogtreecommitdiffstats
path: root/src/flowlayout.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:10:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:10:03 -0600
commitfc6629f90a46a3f304bdba2ecef645c01ed02640 (patch)
tree14f39cc4b99e55d5cbe2b33345b9834e25d2feec /src/flowlayout.cpp
parent0b46312b4c5d893a6e0c29e354038bbdc5a15fdd (diff)
downloadkima-fc6629f90a46a3f304bdba2ecef645c01ed02640.tar.gz
kima-fc6629f90a46a3f304bdba2ecef645c01ed02640.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'src/flowlayout.cpp')
-rw-r--r--src/flowlayout.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/flowlayout.cpp b/src/flowlayout.cpp
index 7f10faf..813ae5c 100644
--- a/src/flowlayout.cpp
+++ b/src/flowlayout.cpp
@@ -181,25 +181,25 @@ bool FlowLayout::hasWidthForHeight() const{
return mOrientation == Qt::Horizontal;
}
-TQSize FlowLayout::tqsizeHint() const{
- //return tqminimumSize();
+TQSize FlowLayout::sizeHint() const{
+ //return minimumSize();
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo( o->tqsizeHint() );
+ size = size.expandedTo( o->sizeHint() );
}
return size;
}
-TQSize FlowLayout::tqminimumSize() const{
+TQSize FlowLayout::minimumSize() const{
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo(o->tqminimumSize());
+ size = size.expandedTo(o->minimumSize());
}
return size;
}
@@ -250,26 +250,26 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
TQPtrList<TQLayoutItem> column; // stores the items of one column
while((layoutItem = it.current()) != 0){
++it;
- //int nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y
- int nextY = y + layoutItem->tqsizeHint().height(); // next y
+ //int nextY = y + layoutItem->sizeHint().height() + spacing(); // next y
+ int nextY = y + layoutItem->sizeHint().height(); // next y
//if( nextY - spacing() > rect.bottom() && width > 0 ) {
if( nextY > rect.bottom() && width > 0 ) {
// next column
y = rect.y(); // reset y
x = x + width + spacing(); // new x
- //nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y with changed y
- nextY = y + layoutItem->tqsizeHint().height(); // next y with changed y
+ //nextY = y + layoutItem->sizeHint().height() + spacing(); // next y with changed y
+ nextY = y + layoutItem->sizeHint().height(); // next y with changed y
width = 0; // reset width for the next column
}
if(!testOnly){
- layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->tqsizeHint() ) );
+ layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->sizeHint() ) );
column.append(layoutItem);
- height += layoutItem->tqsizeHint().height(); // add the height of the current item to the column height
- if( it.current() == 0 || nextY + it.current()->tqsizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
+ height += layoutItem->sizeHint().height(); // add the height of the current item to the column height
+ if( it.current() == 0 || nextY + it.current()->sizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
// calculate real needed width
int rWidth = 0;
for(TQLayoutItem* item = column.first(); item; item = column.next()){
- rWidth = TQMAX( rWidth, item->widget()->tqsizeHint().width() );
+ rWidth = TQMAX( rWidth, item->widget()->sizeHint().width() );
}
// retqlayout the items of the former column
int space = (rect.height() - height) / (column.count() + 1);
@@ -283,7 +283,7 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
}
}
y = nextY;
- width = TQMAX( width, layoutItem->tqsizeHint().width() );
+ width = TQMAX( width, layoutItem->sizeHint().width() );
}
return x + width - rect.x(); // width
}
@@ -296,18 +296,18 @@ int FlowLayout::doLayoutVertical( const TQRect& rect, bool testOnly ){
TQLayoutItem* layoutItem;
while((layoutItem = it.current() ) != 0){
++it;
- //int nextX = x + layoutItem->tqsizeHint().width() + spacing();
- int nextX = x + layoutItem->tqsizeHint().width();
+ //int nextX = x + layoutItem->sizeHint().width() + spacing();
+ int nextX = x + layoutItem->sizeHint().width();
if(nextX - spacing() > rect.right() && height > 0) {
// next line
x = rect.x(); // reset x
//y = y + height + spacing(); // new y
y = y + height; // new y
- //nextX = x + layoutItem->tqsizeHint().width() + spacing(); // next x
- nextX = x + layoutItem->tqsizeHint().width(); // next x
+ //nextX = x + layoutItem->sizeHint().width() + spacing(); // next x
+ nextX = x + layoutItem->sizeHint().width(); // next x
height = 0; // reset height for the next line
}
- const int itemHeight = layoutItem->tqsizeHint().height();
+ const int itemHeight = layoutItem->sizeHint().height();
if(!testOnly)
layoutItem->setGeometry(TQRect(x, y, rect.right(), itemHeight));
x = nextX;